@@ -770,8 +770,9 @@ exchange_mapi_util_get_gal (GPtrArray *contacts_array)
 	ulFlags = TABLE_START;
 	do {
 		count += 0x2;
+		SRowSet = NULL;
 		retval = GetGALTable(global_mapi_session, SPropTagArray, &SRowSet, count, ulFlags);
-		if ((!SRowSet) || (!(SRowSet->aRow))) {
+		if ((!SRowSet) || (!(SRowSet->aRow)) || retval != MAPI_E_SUCCESS) {
 			UNLOCK ();
 			MAPIFreeBuffer (SPropTagArray);
 			return FALSE;
@@ -944,7 +945,10 @@ exchange_mapi_util_modify_recipients (TALLOC_CTX *mem_ctx, mapi_object_t *obj_me
 			set_recipient_properties(mem_ctx, &SRowSet->aRow[last], recipient, TRUE);
 			SRowSet->cRows += 1;
 		} else if (FlagList->aulPropTag[i] == MAPI_RESOLVED) {
-			set_recipient_properties (mem_ctx, &SRowSet->aRow[j], recipient, FALSE);
+			/* FIXME: Even though some recipients are resolved, their mailboxes need not reside 
+			on the same server in case of cluster setups. So lets set ext_lpProps for all recipients.
+			Lets have this fix until we have openchange handling this case better. */
+			set_recipient_properties (mem_ctx, &SRowSet->aRow[j], recipient, TRUE);
 			j += 1;
 		}
 	}
@@ -2147,6 +2151,22 @@ exchange_mapi_create_item (uint32_t olFolder, mapi_id_t fid,
 		retval = SubmitMessage(&obj_message);
 		if (retval != MAPI_E_SUCCESS) {
 			mapi_errstr("SubmitMessage", GetLastError());
+
+			if ((options & MAPI_OPTIONS_DELETE_ON_SUBMIT_FAILURE) != 0) {
+				mid = mapi_object_get_id (&obj_message);
+				mapi_object_release(&obj_message);
+				/* to not release a message object twice */
+				mapi_object_init (&obj_message);
+
+				retval = DeleteMessage (&obj_folder, &mid, 1);
+				if (retval != MAPI_E_SUCCESS) {
+					mapi_errstr ("DeleteMessage", GetLastError ());
+				}
+
+				/* do not forget to set it back to 0, as the function failed */
+				mid = 0;
+			}
+
 			goto cleanup;
 		}
 	}
